---
slug: /iterate
---

# ITERATE

The `ITERATE` statement restarts a loop statement.

The syntax of the `ITERATE` statement is as follows:

```sql
ITERATE label
```

The `ITERATE` statement can be used only in `LOOP`, `REPEAT`, and `WHILE` statements.